==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/ddd/economy_8cpp.js <==
var economy_8cpp =
[
    [ "IsEmptyAction", "d3/d36/structIsEmptyAction.html", "d3/d36/structIsEmptyAction" ],
    [ "PrepareRefitAction", "d1/dbc/structPrepareRefitAction.html", "d1/dbc/structPrepareRefitAction" ],
    [ "ReturnCargoAction", "d6/d8b/structReturnCargoAction.html", "d6/d8b/structReturnCargoAction" ],
    [ "FinalizeRefitAction", "de/d93/structFinalizeRefitAction.html", "de/d93/structFinalizeRefitAction" ],
    [ "ReserveCargoAction", "d9/d0a/structReserveCargoAction.html", "d9/d0a/structReserveCargoAction" ],
    [ "SmallIndustryList", "d9/ddd/economy_8cpp.html#a2e149d77167193be54aead6ca200b8ec", null ],
    [ "AddInflation", "d9/ddd/economy_8cpp.html#aec2cfbafc279e337008ab3f9aad8807c", null ],
    [ "BigMulS", "d9/ddd/economy_8cpp.html#ae2c75e314948645b5e92cc2f65085059", null ],
    [ "CalculateCompanyValue", "d9/ddd/economy_8cpp.html#afb3e4f0a57631ff9889bee9d4d8a75d5", null ],
    [ "ChangeOwnershipOfCompanyItems", "d9/ddd/economy_8cpp.html#a2a17e5e94cb229c1df325b0ab4a50f8a", null ],
    [ "CmdBuyCompany", "d9/ddd/economy_8cpp.html#a3be0fee18d184e49664ff3240e32356c", null ],
    [ "CmdBuyShareInCompany", "d9/ddd/economy_8cpp.html#ac15f299c1279ba768ae0299ddbb5e66c", null ],
    [ "CmdSellShareInCompany", "d9/ddd/economy_8cpp.html#af2b17da2e6703eaa283e315d4eaa8790", null ],
    [ "CompaniesGenStatistics", "d9/ddd/economy_8cpp.html#aeb420e09d6862abc4e2c99aaaf6467b1", null ],
    [ "CompaniesMonthlyLoop", "d9/ddd/economy_8cpp.html#ad53f0cc5d5234d1ca999abe3545b2153", null ],
    [ "CompaniesPayInterest", "d9/ddd/economy_8cpp.html#a34f921895975bb7a334dc437a697dd4b", null ],
    [ "CompanyCheckBankrupt", "d9/ddd/economy_8cpp.html#adf209eb2b0b8aec18d3b1e49f2e77e8e", null ],
    [ "DeliverGoods", "d9/ddd/economy_8cpp.html#ab335b74ecdd811e71ada06a98f6643ad", null ],
    [ "DeliverGoodsToIndustry", "d9/ddd/economy_8cpp.html#a09cabc602709a0865b5b41ceea7a23d3", null ],
    [ "DoAcquireCompany", "d9/ddd/economy_8cpp.html#a33e79da33974eab2e341ae298a5358fa", null ],
    [ "GetAmountOwnedBy", "d9/ddd/economy_8cpp.html#af5cbc847ddb990205c6890cc5e74d103", null ],
    [ "GetLoadAmount", "d9/ddd/economy_8cpp.html#a8ea16d0da4a782737b89601a00dfb85a", null ],
    [ "GetPrice", "d9/ddd/economy_8cpp.html#aa67a76f1d56249d78fe298a23b8e4ca1", null ],
    [ "GetTransportedGoodsIncome", "d9/ddd/economy_8cpp.html#a4606079c6012b2efcf62f17474351b9e", null ],
    [ "HandleEconomyFluctuations", "d9/ddd/economy_8cpp.html#a0e455b8cd7d8f3ed646a8cc3aeb20e88", null ],
    [ "HandleStationRefit", "d9/ddd/economy_8cpp.html#aeb0b7ae27d2d66a2db4503dce1dee0ba", null ],
    [ "InitializeEconomy", "d9/ddd/economy_8cpp.html#ad05533d6112fd2212c3f2c52505b0059", null ],
    [ "IterateVehicleParts", "d9/ddd/economy_8cpp.html#aba78ed90d32c8157d55988698b8dfc96", null ],
    [ "LoadUnloadStation", "d9/ddd/economy_8cpp.html#a42f50fd8ede3e8db70de5f01083dd02e", null ],
    [ "LoadUnloadVehicle", "d9/ddd/economy_8cpp.html#a4768777aff8aec1014dc9064f759af2d", null ],
    [ "PrepareUnload", "d9/ddd/economy_8cpp.html#a6ae403e6faea663062c593326c32abda", null ],
    [ "RecomputePrices", "d9/ddd/economy_8cpp.html#a441bd16aa27575f9f68e630c346bb361", null ],
    [ "ReserveConsist", "d9/ddd/economy_8cpp.html#a90dcdde649f30f05dc584bc3fdbb867d", null ],
    [ "ResetPriceBaseMultipliers", "d9/ddd/economy_8cpp.html#ae954c8915dc923b753b125fe73ab59f8", null ],
    [ "SetPriceBaseMultiplier", "d9/ddd/economy_8cpp.html#aa32cbd13d56702d63ac0d2da7b66223d", null ],
    [ "StartupEconomy", "d9/ddd/economy_8cpp.html#a0d27f2071ef5e67d88f9393d1a10877a", null ],
    [ "StartupIndustryDailyChanges", "d9/ddd/economy_8cpp.html#aff990757aec94219ac72ccdc13bbc73f", null ],
    [ "TriggerIndustryProduction", "d9/ddd/economy_8cpp.html#ab2a2259652bc0e00cacb9263f4793290", null ],
    [ "UpdateCompanyRatingAndValue", "d9/ddd/economy_8cpp.html#a19ecebd3da338f876355a3dabd214237", null ],
    [ "UpdateLoadUnloadTicks", "d9/ddd/economy_8cpp.html#a0842be5602c83b3bf0c9e04c8460440b", null ],
    [ "_additional_cash_required", "d9/ddd/economy_8cpp.html#a10d3d57726c69644780acd57feca5ef1", null ],
    [ "_cargo_delivery_destinations", "d9/ddd/economy_8cpp.html#a66465f45a88d91a461184661b62c02a0", null ],
    [ "_cargo_payment_pool", "d9/ddd/economy_8cpp.html#a721a3fc1970a888ceadee812a13009e1", null ],
    [ "_economy", "d9/ddd/economy_8cpp.html#a0c14d41ad53d15540cb60322ab171ef2", null ],
    [ "_price", "d9/ddd/economy_8cpp.html#ac23bebd0cfef733bb700303c5e0d6c20", null ],
    [ "_price_base_multiplier", "d9/ddd/economy_8cpp.html#a4be6fa39c0b0922cbb2adf645abccf7c", null ],
    [ "_score_info", "d9/ddd/economy_8cpp.html#a29dc509ad4c0b130e52cc2534c8f3767", null ],
    [ "_score_part", "d9/ddd/economy_8cpp.html#a28c478603f9f0b9281344d3b27cd5c2d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/ddd/economy_8cpp.js <==
var economy_8cpp =
[
    [ "IsEmptyAction", "d3/d36/structIsEmptyAction.html", "d3/d36/structIsEmptyAction" ],
    [ "PrepareRefitAction", "d1/dbc/structPrepareRefitAction.html", "d1/dbc/structPrepareRefitAction" ],
    [ "ReturnCargoAction", "d6/d8b/structReturnCargoAction.html", "d6/d8b/structReturnCargoAction" ],
    [ "FinalizeRefitAction", "de/d93/structFinalizeRefitAction.html", "de/d93/structFinalizeRefitAction" ],
    [ "ReserveCargoAction", "d9/d0a/structReserveCargoAction.html", "d9/d0a/structReserveCargoAction" ],
    [ "SmallIndustryList", "d9/ddd/economy_8cpp.html#a2d8a48a372b109a012fd655e2ee92955", null ],
    [ "AddInflation", "d9/ddd/economy_8cpp.html#aec2cfbafc279e337008ab3f9aad8807c", null ],
    [ "BigMulS", "d9/ddd/economy_8cpp.html#ae2c75e314948645b5e92cc2f65085059", null ],
    [ "CalculateCompanyValue", "d9/ddd/economy_8cpp.html#afb3e4f0a57631ff9889bee9d4d8a75d5", null ],
    [ "ChangeOwnershipOfCompanyItems", "d9/ddd/economy_8cpp.html#a2a17e5e94cb229c1df325b0ab4a50f8a", null ],
    [ "CmdBuyCompany", "d9/ddd/economy_8cpp.html#a3be0fee18d184e49664ff3240e32356c", null ],
    [ "CmdBuyShareInCompany", "d9/ddd/economy_8cpp.html#ac15f299c1279ba768ae0299ddbb5e66c", null ],
    [ "CmdSellShareInCompany", "d9/ddd/economy_8cpp.html#af2b17da2e6703eaa283e315d4eaa8790", null ],
    [ "CompaniesGenStatistics", "d9/ddd/economy_8cpp.html#aeb420e09d6862abc4e2c99aaaf6467b1", null ],
    [ "CompaniesMonthlyLoop", "d9/ddd/economy_8cpp.html#ad53f0cc5d5234d1ca999abe3545b2153", null ],
    [ "CompaniesPayInterest", "d9/ddd/economy_8cpp.html#a34f921895975bb7a334dc437a697dd4b", null ],
    [ "CompanyCheckBankrupt", "d9/ddd/economy_8cpp.html#adf209eb2b0b8aec18d3b1e49f2e77e8e", null ],
    [ "DeliverGoods", "d9/ddd/economy_8cpp.html#ab335b74ecdd811e71ada06a98f6643ad", null ],
    [ "DeliverGoodsToIndustry", "d9/ddd/economy_8cpp.html#a0b37bb7d65fad60e9695b4254b77436f", null ],
    [ "DoAcquireCompany", "d9/ddd/economy_8cpp.html#a33e79da33974eab2e341ae298a5358fa", null ],
    [ "GetAmountOwnedBy", "d9/ddd/economy_8cpp.html#af5cbc847ddb990205c6890cc5e74d103", null ],
    [ "GetLoadAmount", "d9/ddd/economy_8cpp.html#a8ea16d0da4a782737b89601a00dfb85a", null ],
    [ "GetPrice", "d9/ddd/economy_8cpp.html#aa67a76f1d56249d78fe298a23b8e4ca1", null ],
    [ "GetTransportedGoodsIncome", "d9/ddd/economy_8cpp.html#a4606079c6012b2efcf62f17474351b9e", null ],
    [ "HandleEconomyFluctuations", "d9/ddd/economy_8cpp.html#a0e455b8cd7d8f3ed646a8cc3aeb20e88", null ],
    [ "HandleStationRefit", "d9/ddd/economy_8cpp.html#aeb0b7ae27d2d66a2db4503dce1dee0ba", null ],
    [ "InitializeEconomy", "d9/ddd/economy_8cpp.html#ad05533d6112fd2212c3f2c52505b0059", null ],
    [ "IterateVehicleParts", "d9/ddd/economy_8cpp.html#aba78ed90d32c8157d55988698b8dfc96", null ],
    [ "LoadUnloadStation", "d9/ddd/economy_8cpp.html#a42f50fd8ede3e8db70de5f01083dd02e", null ],
    [ "LoadUnloadVehicle", "d9/ddd/economy_8cpp.html#a4768777aff8aec1014dc9064f759af2d", null ],
    [ "MayLoadUnderExclusiveRights", "d9/ddd/economy_8cpp.html#a01d36096d334fdc9105167d1b127330b", null ],
    [ "PrepareUnload", "d9/ddd/economy_8cpp.html#a6ae403e6faea663062c593326c32abda", null ],
    [ "RecomputePrices", "d9/ddd/economy_8cpp.html#a441bd16aa27575f9f68e630c346bb361", null ],
    [ "ReserveConsist", "d9/ddd/economy_8cpp.html#a90dcdde649f30f05dc584bc3fdbb867d", null ],
    [ "ResetPriceBaseMultipliers", "d9/ddd/economy_8cpp.html#ae954c8915dc923b753b125fe73ab59f8", null ],
    [ "SetPriceBaseMultiplier", "d9/ddd/economy_8cpp.html#aa32cbd13d56702d63ac0d2da7b66223d", null ],
    [ "StartupEconomy", "d9/ddd/economy_8cpp.html#a0d27f2071ef5e67d88f9393d1a10877a", null ],
    [ "StartupIndustryDailyChanges", "d9/ddd/economy_8cpp.html#aff990757aec94219ac72ccdc13bbc73f", null ],
    [ "TriggerIndustryProduction", "d9/ddd/economy_8cpp.html#ab2a2259652bc0e00cacb9263f4793290", null ],
    [ "UpdateCompanyRatingAndValue", "d9/ddd/economy_8cpp.html#a19ecebd3da338f876355a3dabd214237", null ],
    [ "UpdateLoadUnloadTicks", "d9/ddd/economy_8cpp.html#a0842be5602c83b3bf0c9e04c8460440b", null ],
    [ "_additional_cash_required", "d9/ddd/economy_8cpp.html#a10d3d57726c69644780acd57feca5ef1", null ],
    [ "_cargo_delivery_destinations", "d9/ddd/economy_8cpp.html#a66465f45a88d91a461184661b62c02a0", null ],
    [ "_cargo_payment_pool", "d9/ddd/economy_8cpp.html#a721a3fc1970a888ceadee812a13009e1", null ],
    [ "_economy", "d9/ddd/economy_8cpp.html#a0c14d41ad53d15540cb60322ab171ef2", null ],
    [ "_price", "d9/ddd/economy_8cpp.html#ac23bebd0cfef733bb700303c5e0d6c20", null ],
    [ "_price_base_multiplier", "d9/ddd/economy_8cpp.html#a4be6fa39c0b0922cbb2adf645abccf7c", null ],
    [ "_score_info", "d9/ddd/economy_8cpp.html#a29dc509ad4c0b130e52cc2534c8f3767", null ],
    [ "_score_part", "d9/ddd/economy_8cpp.html#a28c478603f9f0b9281344d3b27cd5c2d", null ]
];
